@@ -3,22 +3,20 @@ package Eval::LineNumbers;
 
 use warnings;
 use strict;
-require Exporter;
-our @ISA = qw(Exporter);
-our @EXPORT = qw();
+
+use Exporter 5.57 'import';
 our @EXPORT_OK = qw(eval_line_numbers);
 
-our $VERSION = 0.32;
+our $VERSION = 0.33;
 
 sub eval_line_numbers
 {
-	my $level = 0;
-	$level = shift
-		if $_[0] =~ /^\d\d?$/;
-	my($pkg, $file, $line) = caller($level);
+	my(undef, $file, $line) = caller(
+		# Optional first arg is the caller level
+		$_[0] =~ /^[0-9]+$/ ? (shift) : 0
+	);
 	$line++;
-	my $val = qq{#line $line "$file"\n}.join('',@_);
-	return $val;
+	return join('', qq{#line $line "$file"\n}, @_)
 }
 1;
 
@@ -36,6 +34,8 @@ Eval::LineNumbers - Add line numbers to heredoc blocks that contain perl source
    code
  END_HEREIS
 
+ eval eval_line_numbers($caller_level, $code)
+
 =head1 DESCRIPTION
 
 Add a C<#line "this-file" 392> comment to heredoc/hereis text that is going
@@ -45,6 +45,22 @@ Please note: when you embed C<\n> in your code, it gets expanded in
 double-quote hereis documents so it will mess up your line numbering.
 Use C<\\n> instead when you can.
 
+=head2 Caller Level Example
+
+The second form of eval_line_numbers where a caller-level is provided
+is for the situation where the code is generated in one place and 
+eval'ed in another place.  The caller level should be the number of
+stack levels between where the heredoc was created and where it is
+eval'ed.
+
+ sub example {
+   return <<END_HEREIS
+     code
+END_HEREIS
+ }
+
+ eval eval_line_numbers(1, example())
+
 =head1 LICENSE
 
 Copyright (C) 2009 David Muir Sharnoff.
